@@ -31,7 +31,6 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
 import os, sys
-from copy import deepcopy
 here = os.path.abspath(os.path.dirname(__file__))
 
 
@@ -65,7 +64,6 @@ from rocketcea.separated_Cf import ambientCf, sepNozzleCf
 #
 # gravitational conversion factor
 GC = 32.174
-DEEP_COPY_L = [None] # will hold deepcopy of CEA_Obj (fixes mass/mole fraction calls)
 
 _last_called = None # remember the last object to read the datafile
 _NLines_Max_ever = 0 # make sure to overwrite any lines from previous calls
@@ -347,12 +345,11 @@ class CEA_Obj(object):
                 if fp:
                     fp.close()
 
-        DEEP_COPY_L[0] = deepcopy( self )
 
     def setupCards(self, Pc=100.0, MR=1.0, eps=40.0, subar=None, PcOvPe=None, frozen=0,
                    ERphi=None, ERr=None, frozenAtThroat=0, short_output=0,
                    show_transport=0, pc_units='psia', output='calories',
-                   show_mass_frac=False):
+                   show_mass_frac=False, fac_CR=None):
         '''
         Set up card deck and call CEA FORTRAN code.::
 
@@ -362,13 +359,11 @@ class CEA_Obj(object):
         #: pc_units = 'psia', 'bar', 'atm', 'mmh'(mm of mercury)
         #: frozen flag (0=equilibrium, 1=frozen)
         #: frozenAtThroat flag, 0=frozen in chamber, 1=frozen at throat
+        #: fac_CR, Contraction Ratio of finite area combustor
         '''
 
         global _last_called, _NLines_Max_ever
         
-        self = DEEP_COPY_L[0]
-
-
         N = 1
         for line in self.cea_deck:
             if type(line) == type("str"):
@@ -434,11 +429,21 @@ class CEA_Obj(object):
         
         # ------------ Pc/Pe String -------------
         pcope_str = make_inp_str( " pi/p=", PcOvPe )
+        
 
         # ------------------------------------------------
         # set up rocket line with Pc, PC/Pe and Epsilon
         set_py_cea_line(N," rocket %s  %s"%(eqfrStr,pc_str) + subar_str + pcope_str + eps_str )
 
+        
+        # ------------ Finite Area Combustor String ------
+        
+        if fac_CR is not None:
+            N += 1
+            fac_str = ' fac ' + make_inp_str(" ac/at=", fac_CR )
+                    
+            set_py_cea_line(N, fac_str )
+        
 
         N += 1
 
@@ -545,7 +550,7 @@ class CEA_Obj(object):
         #    for i in range(3):
         #        py_cea.comp.en[k-1,i] = 0.0
         #        py_cea.therm.mw[k-1] = 0.0
-        #    if k>50:
+        #    if k>=50:
         #        break
             
             
@@ -555,7 +560,8 @@ class CEA_Obj(object):
 
     def get_full_cea_output(self, Pc=100.0, MR=1.0, eps=40.0, subar=None, PcOvPe=None,
                             frozen=0, frozenAtThroat=0, short_output=0, show_transport=1,
-                            pc_units='psia', output='calories', show_mass_frac=False):
+                            pc_units='psia', output='calories', show_mass_frac=False,
+                            fac_CR=None):
         """
         Get the full output file created by CEA. Return as a string.
         #: pc_units = 'psia', 'bar', 'atm', 'mmh'(mm of mercury)
@@ -571,7 +577,8 @@ class CEA_Obj(object):
                          frozen=frozen, frozenAtThroat=frozenAtThroat, 
                          short_output=short_output,
                          show_transport=show_transport, pc_units=pc_units,
-                         output=output, show_mass_frac=show_mass_frac)
+                         output=output, show_mass_frac=show_mass_frac,
+                         fac_CR=fac_CR)
 
         self.makeOutput = save_flag # restore makeOutput
 
@@ -889,16 +896,14 @@ class CEA_Obj(object):
         #: molWtD dictionary: index=species: value=molecular weight
         #: massFracD dictionary: index=species: value=[massfrac_chm, massfrac_tht, massfrac_exit]
         """
+
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen, frozenAtThroat=frozenAtThroat)
         
-        #s = self.get_full_cea_output( Pc=Pc, MR=MR, eps=eps, subar=None, PcOvPe=None,
-        #                    frozen=frozen, frozenAtThroat=frozenAtThroat, short_output=0, show_transport=1,
-        #                    pc_units='psia', output='calories', show_mass_frac=True)
-        #print('Full Output:',s)
-        
         massFracD = {} # index=species: value=[massfrac_chm, massfrac_tht, massfrac_exit]
         molWtD    = {} # index=species: value=molecular weight
-        for k,p in enumerate(py_cea.cdata.prod):
+        
+        for k in range( py_cea.indx.ngc ):
+            p = py_cea.cdata.prod[k]
             p = p.decode("utf-8").strip()
             if p:
                 sL = []
@@ -935,11 +940,14 @@ class CEA_Obj(object):
         #: molWtD dictionary: index=species: value=molecular weight
         #: moleFracD dictionary: index=species: value=[molefrac_chm, molefrac_tht, molefrac_exit]
         """
+        
         self.setupCards( Pc=Pc, MR=MR, eps=eps, frozen=frozen, frozenAtThroat=frozenAtThroat)
         
         moleFracD = {} # index=species: value=[molefrac_chm, molefrac_tht, molefrac_exit]
         molWtD    = {} # index=species: value=molecular weight
-        for k,p in enumerate(py_cea.cdata.prod):
+        
+        for k in range( py_cea.indx.ngc ):
+            p = py_cea.cdata.prod[k]
             p = p.decode("utf-8").strip()
             if p:
                 sL = []
